==> ph-schematron-5.0.4-sources.jar: com/helger/schematron/svrl/SVRLSuccessfulReport.java <==
/**
 * Copyright (C) 2014-2018 Philip Helger (www.helger.com)
 * philip[at]helger[dot]com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.helger.schematron.svrl;

import java.util.function.Function;

import javax.annotation.Nonnull;
import javax.annotation.concurrent.Immutable;

import org.oclc.purl.dsdl.svrl.SuccessfulReport;

import com.helger.commons.error.level.IErrorLevel;

/**
 * A wrapper around {@link SuccessfulReport} with easier error level handling.
 *
 * @author Philip Helger
 */
@Immutable
public class SVRLSuccessfulReport extends AbstractSVRLMessage
{
  public SVRLSuccessfulReport (@Nonnull final SuccessfulReport aSuccessfulReport)
  {
    this (aSuccessfulReport, SVRLHelper::getErrorLevelFromSuccessfulReport);
  }

  public SVRLSuccessfulReport (@Nonnull final SuccessfulReport aSuccessfulReport,
                               @Nonnull final Function <? super SuccessfulReport, ? extends IErrorLevel> aErrLevelProvider)
  {
    this (aSuccessfulReport, x -> SVRLHelper.getBeautifiedLocation (x.getLocation ()), aErrLevelProvider);
  }

  public SVRLSuccessfulReport (@Nonnull final SuccessfulReport aSuccessfulReport,
                               @Nonnull final Function <? super SuccessfulReport, String> aLocationProvider,
                               @Nonnull final Function <? super SuccessfulReport, ? extends IErrorLevel> aErrLevelProvider)
  {
    super (aSuccessfulReport.getDiagnosticReference (),
           aSuccessfulReport.getText (),
           aLocationProvider.apply (aSuccessfulReport),
           aSuccessfulReport.getTest (),
           aSuccessfulReport.getRole (),
           aErrLevelProvider.apply (aSuccessfulReport));
  }
}

==> ph-schematron-5.6.5-sources.jar: com/helger/schematron/svrl/SVRLSuccessfulReport.java <==
/**
 * Copyright (C) 2014-2020 Philip Helger (www.helger.com)
 * philip[at]helger[dot]com
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.helger.schematron.svrl;

import java.util.function.Function;

import javax.annotation.Nonnull;
import javax.annotation.concurrent.Immutable;

import com.helger.commons.error.level.IErrorLevel;
import com.helger.schematron.svrl.jaxb.SuccessfulReport;

/**
 * A wrapper around {@link SuccessfulReport} with easier error level handling.
 *
 * @author Philip Helger
 */
@Immutable
public class SVRLSuccessfulReport extends AbstractSVRLMessage
{
  public SVRLSuccessfulReport (@Nonnull final SuccessfulReport aSuccessfulReport)
  {
    this (aSuccessfulReport, SVRLHelper::getErrorLevelFromSuccessfulReport);
  }

  public SVRLSuccessfulReport (@Nonnull final SuccessfulReport aSuccessfulReport,
                               @Nonnull final Function <? super SuccessfulReport, ? extends IErrorLevel> aErrLevelProvider)
  {
    this (aSuccessfulReport, x -> SVRLHelper.getBeautifiedLocation (x.getLocation ()), aErrLevelProvider);
  }

  public SVRLSuccessfulReport (@Nonnull final SuccessfulReport aSuccessfulReport,
                               @Nonnull final Function <? super SuccessfulReport, String> aLocationProvider,
                               @Nonnull final Function <? super SuccessfulReport, ? extends IErrorLevel> aErrLevelProvider)
  {
    super (aSuccessfulReport.getDiagnosticReference (),
           SVRLHelper.getAsString (aSuccessfulReport.getText ()),
           aLocationProvider.apply (aSuccessfulReport),
           aSuccessfulReport.getTest (),
           aSuccessfulReport.getRole (),
           aErrLevelProvider.apply (aSuccessfulReport));
  }
}
